/*
 * hey_bad.cc
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file hey_bad.cc
 *
 * Test invalid inputs to a HeyParser instance.
 *
 * @sa hey_good.cc
 */

#include "config.h"

#if !defined(DEBUG)
#define DEBUG
#endif

#include <iostream>

#include "HeyParser.hh"

int main(int argc, const char *argv[])
{
    int retval = EXIT_SUCCESS;

    try
    {
	HeyParser hp(1, argv);
	cerr << "HeyParser accepts empty argument list?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }

    try
    {
	const char *hp_argv[] = {
	    "hey", "", "list",
	};
	
	HeyParser hp(3, hp_argv);
	cerr << "HeyParser accepts empty server name?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }

    try
    {
	const char *hp_argv[] = {
	    "hey", "ior", "foo",
	};
	
	HeyParser hp(3, hp_argv);
	cerr << "HeyParser accepts bogus verb?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }

    try
    {
	const char *hp_argv[] = {
	    "hey", "ior", "set",
	};
	
	HeyParser hp(3, hp_argv);

	hp.to();
	cerr << "HeyParser.to works without 'to' argument?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }
    
    try
    {
	const char *hp_argv[] = {
	    "hey", "ior", "set", "foo", "to",
	};
	
	HeyParser hp(5, hp_argv);

	hp.to();
	cerr << "HeyParser.to works without 'to' value?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }
    
    try
    {
	const char *hp_argv[] = {
	    "hey", "ior", "create", "foo", "with",
	};
	
	HeyParser hp(5, hp_argv);

	hp.to();
	cerr << "HeyParser.with works with no arguments?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }
    
    try
    {
	const char *hp_argv[] = {
	    "hey", "ior", "create", "foo", "with", "bar",
	};
	
	HeyParser hp(6, hp_argv);

	hp.to();
	cerr << "HeyParser.with works with odd number of arguments?\n";
	retval = EXIT_FAILURE;
    }
    catch(HeyParserException &e)
    {
#if defined(DEBUG)
	cerr << e << endl;
#endif
    }
    
    return( retval );
}
