/*
 * BasicTaskQosketImpl.cc
 *
 * Copyright (c) 2003, 2004 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file BasicTaskQosketImpl.cc
 *
 * Implementation of the BasicTaskQosketImpl class.
 */

#include "config.h"

#include <assert_pp.h>

#include "BasicTaskCallbackImpl.hh"
#include "BasicTaskQosketImpl.hh"

void BasicTaskQosketImpl::initSysconds(const quo::QuoKernel_ptr &kernel)
    throw (CORBA::SystemException)
{
    quo::SysCond_var sc;

    require(kernel != NULL);

    /* Get the syscond from the kernel. */
    sc = kernel->bindSysCond("DeadlinesMissed",
			     "quo::ValueSC",
			     "quo_sc::ValueSCImpl");

    this->myDeadlinesMissed =
	quo::ValueSC::_duplicate(quo::ValueSC::_narrow(sc.in()));
    this->myDeadlinesMissed->longValue(0); /* Set the initial value */
    
    /* Get the syscond from the kernel. */
    sc = kernel->bindSysCond("LastStatus",
			     "quo::ValueSC",
			     "quo_sc::ValueSCImpl");
    
    this->myLastStatus =
	quo::ValueSC::_duplicate(quo::ValueSC::_narrow(sc.in()));
    this->myLastStatus->longValue(0); /* Set the initial value */
}

void BasicTaskQosketImpl::initCallbacks(const CORBA::ORB_ptr &orb)
    throw (CORBA::SystemException)
{
    Qosket::Basic::BasicTaskCallback_var btc;
    BasicTaskCallbackImpl *btci;

    require(!CORBA::is_nil(orb));

    btci = new BasicTaskCallbackImpl();
    btc = btci->_this();
    this->myCallback = Qosket::Basic::BasicTaskCallback::_duplicate(btc.in());
}

quo::ValueSC_ptr BasicTaskQosketImpl::DeadlinesMissed(void)
    throw (CORBA::SystemException)
{
    quo::ValueSC_var retval;

    retval = this->myDeadlinesMissed;
    return( retval._retn() );
}

quo::ValueSC_ptr BasicTaskQosketImpl::LastStatus(void)
    throw (CORBA::SystemException)
{
    quo::ValueSC_var retval;

    retval = this->myLastStatus;
    return( retval._retn() );
}

quo::Callback_ptr BasicTaskQosketImpl::Callback(void)
    throw (CORBA::SystemException)
{
    Qosket::Basic::BasicTaskCallback_var retval;

    retval = this->myCallback;
    return( retval._retn() );
}

CORBA::ULongLong BasicTaskQosketImpl::RUsage(void)
    throw (CORBA::SystemException)
{
    CORBA::ULongLong retval = 0;
    struct rusage ru;

    if( getrusage(RUSAGE_SELF, &ru) == 0 )
    {
	retval = ru.ru_utime.tv_usec;
	retval += ru.ru_utime.tv_sec * 1000000;
    }
    else
    {
	throw CORBA::UNKNOWN();
    }
    return( retval );
}
